phoneclientserver/phoneclient/Inc/UssdWrapper/MPhCltUssdNoteControllerCallBack.h
branchRCL_3
changeset 20 987c9837762f
parent 19 7d48bed6ce0c
--- a/phoneclientserver/phoneclient/Inc/UssdWrapper/MPhCltUssdNoteControllerCallBack.h	Tue Aug 31 15:45:17 2010 +0300
+++ b/phoneclientserver/phoneclient/Inc/UssdWrapper/MPhCltUssdNoteControllerCallBack.h	Wed Sep 01 12:15:03 2010 +0100
@@ -27,7 +27,7 @@
 
 /**
 *  Abstract interface for handling the notify events from note controller.
 *  User derives his class from this and implements GlobalWaitNoteHidden().
 *
 *  @lib phoneclient.lib
 *  @since 9.1
@@ -39,11 +39,11 @@
     public: // New functions
 
         /**
         * Called when global wait note is hidden, to background.
         * 
         * @param aError Error code.
         */    
-        virtual void GlobalWaitNoteHidden() = 0;
+        virtual void GlobalWaitNoteDismissedL( const TInt aError ) = 0;
     };
@@ -27,7 +27,7 @@
 /**
 *  Abstract interface for handling the notify events from note controller.
-*  User derives his class from this and implements GlobalWaitNoteHidden().
+*  User derives his class from this and implements GlobalWaitNoteDismissedL().
 *
 *  @lib phoneclient.lib
@@ -39,11 +39,11 @@
 
         /**
-        * Called when global wait note is hidden, to background.
+        * Called when global wait note is dismissed.
         * 
         * @param aError Error code.